<?php

	// Tumblr用のライブラリの読み込み
	require './tumblr-oauth-library.php' ;

	// 設定
	$access_token = '' ;	// アクセストークン
	$access_token_secret = '' ;	// アクセストークンシークレット
	$request_url = 'https://api.tumblr.com/v2/user/info' ;
	$request_method = 'GET' ;

	// JSONデータとレスポンスヘッダーをセット(配列)で取得する
	list( $json , $header ) = tumblr_oauth( $request_url , $request_method , array( 'oauth_token' => $access_token , 'oauth_token_secret' => $access_token_secret ) , 1 ) ;

	// オブジェクト形式に変換する
	$obj = json_decode( $json ) ;

	// HTML用
	$html = '' ;

	// エラー判定
	if( !$obj || !isset( $obj->response->user->name ) || !isset( $obj->response->user->likes ) || !isset( $obj->response->user->following ) )
	{
		$html .= '<p><mark>データを取得できませんでした…。</mark></p>' ;
	}
	else
	{
		// 各データ
		$name = $obj->response->user->name ;		// ユーザー名
		$likes = $obj->response->user->likes ;		// スキをした回数
		$follow = $obj->response->user->following ;		// フォロー数

		// 出力
		$html .= '<h2>ユーザー情報</h2>' ;
		$html .= '<dl>' ;
		$html .= 	'<dt>名前</dt>' ;
		$html .= 		'<dd>' . $name . '</dd>' ;
		$html .= 	'<dt>スキをした回数</dt>' ;
		$html .= 		'<dd>' . $likes . '回</dd>' ;
		$html .= 	'<dt>フォロー数</dt>' ;
		$html .= 		'<dd>' . $follow . 'ブログ</dd>' ;
		$html .= '</dl>' ;

		// 個々の所有ブログの情報を読み込む
		if( isset( $obj->response->user->blogs ) && !empty( $obj->response->user->blogs ) )
		{
			// 出力
			$html .= '<h2>所有ブログ</h2>' ;

			// 各ブログのデータを解析
			foreach( $obj->response->user->blogs as $item )
			{
				// 各データ
				$blog_name = $item->title ;		// ブログ名
				$blog_url = $item->url ;		// ブログURL
				$blog_follower = $item->followers ;		// フォロワー数
				$blog_updated = date( 'Y/m/d H:i' , $item->updated ) ;		// 最終更新時刻(ついでに整形)
				$blog_posts = $item->posts ;		// 投稿数

				// 出力
				$html .= '<dl>' ;
				$html .= 	'<dt>名前</dt>' ;
				$html .= 		'<dd>' . $blog_name . '</dd>' ;
				$html .= 	'<dt>フォロワー数</dt>' ;
				$html .= 		'<dd>' . $blog_follower . '人</dd>' ;

				// 投稿がある場合のみ
				if( $blog_posts )
				{
					$html .= 	'<dt>最終更新時刻</dt>' ;
					$html .= 		'<dd>' . $blog_updated . '</dd>' ;
					$html .= 	'<dt>投稿数</dt>' ;
					$html .= 		'<dd>' . $blog_posts . '</dd>' ;
				}

				$html .= '</dl>' ;
			}
		}
	}

	// 取得したデータ
	$html .= '<h2>取得したデータ</h2>' ;
	$html .= '<p>下記のデータを取得できました。</p>' ;
	$html .= 	'<h3>JSON</h3>' ;
	$html .= 	'<p><textarea rows="8">' . $json . '</textarea></p>' ;
	$html .= 	'<h3>レスポンスヘッダー</h3>' ;
	$html .= 	'<p><textarea rows="8">' . $header . '</textarea></p>' ;

	// アプリケーション連携の解除
	$html .= '<h2>アプリケーション連携の解除</h2>' ;
	$html .= '<p>このアプリケーションとの連携は、下記設定ページで解除することができます。</p>' ;
	$html .= '<p><a href="https://www.tumblr.com/settings/apps" target="_blank">https://www.tumblr.com/settings/apps</a></p>' ;

?><!DOCTYPE html>
<html>
	<head>
		<meta charset="UTF-8">
		<meta name="robots" content="noindex,nofollow">

		<!-- ビューポートの設定 -->
		<meta name="viewport" content="width=device-width, initial-scale=1.0">

		<title>Tumblr APIでユーザーデータを取得するサンプルデモ</title><!-- 

/********************************************************************************

	SYNCER 〜 知識、感動をみんなと同期(Sync)するブログ

	* 配布場所
	https://syncer.jp/tumblr-api-matome

	* 動作確認
	https://syncer.jp/tumblr-api-matome/demo/get-user-data.php

	* 最終更新日時
	2015/08/03 04:18

	* 作者
	あらゆ

	** 連絡先
	Twitter: https://twitter.com/arayutw
	Facebook: https://www.facebook.com/arayutw
	Google+: https://plus.google.com/114918692417332410369/
	E-mail: info@syncer.jp

	※ バグ、不具合の報告、提案、ご要望など、お待ちしております。
	※ 申し訳ありませんが、ご利用者様、個々の環境における問題はサポートしていません。

********************************************************************************/

		-->
	</head>
<body>



<?php echo $html ?>


<p style="text-align:center"><a href="https://syncer.jp/tumblr-api-matome">配布元: Syncer</a></p>






</body>
</html>
